"""Models package for the PlayStation API wrapper.

This package defines the data models used throughout the API wrapper. These models represent structured responses from
the API and provide a clean interface for accessing and manipulating API data.

Modules in this package include:

- Typed models that map to API response schemas.
- Helper classes for serialization and deserialization.
- Data validation utilities.

"""

from psnawp_api.models.client import Client
from psnawp_api.models.game_title import GameTitle
from psnawp_api.models.group import Group
from psnawp_api.models.search import SearchDomain, UniversalSearch
from psnawp_api.models.title_stats import TitleStats, TitleStatsIterator
from psnawp_api.models.user import User

__all__ = [
    "Client",
    "GameTitle",
    "Group",
    "SearchDomain",
    "TitleStats",
    "TitleStatsIterator",
    "UniversalSearch",
    "User",
]
